/*
 * Copyright by Marco Savegnago.  All rights reserved.
 * This software may be freely distributed and used, but it may not
 * under any circumstances be sold by anyone other than the author.
 * It may be distributed by a commercial company as long as it is
 * for no cost.
 *
 ******************************* Creazione file *******************************
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :

	Le funzioni che seguono:

		GetPrivateProfileInt
		GetPrivateProfileString
		GetProfileInt
		GetProfileString

	ricreano il comportamento delle funzioni di gestione dei file INI in DOS.

	Il file INI e' un file di testo liberamente modificabile con un text
	editor ASCII che in Win16 contiene le impostazioni dei programmi applicativi
	oltre che del sistema operativo.
	All'intero di un file INI e' possibile memorizzare parametri sottoforma
	di stringhe (che poi devono venir opportunamente trattati dal programma
	applicativo) in sezioni distinte, modificare il valori etc.

	Rispetto alla gestione presente in Windows in questa implementazione
	e' possibile inserire commenti sia di linea che di blocco usando la normale
	sintassi C/C++ o ASM.

	Oltre a questo e' possibile rimuvere un intera sezione del file (ad
	esempio se si vogliono cancellare completamente i dati di configurazione
	per evitare sovrapposizioni).


	Un tipico file e' composto come segue:

	file PROVA.INI

	[SECTION1]
	ITEM1=TEST
	ITEM2=TEST

	// This is a line comment 1
	; This is a line comment 2
	! This is a line comment 2

	I block comment sono come quelli del normale C

	[SECTION2]
	ITEM1=TEST
	ITEM2=TEST
*/

#include	<string.h>
#include	<ctype.h>
#include	<stdlib.h>
#include	<stdio.h>
#include	<dir.h>
#include	"profile.h"
#include	"tdef.h"

/******************* Prototipi delle funzioni di servizio *********************
*--------------------------------------|--------------------------------------*/

/****************************** Variabili locali ******************************
*--------------------------------------|--------------------------------------*/

/***************************** Variabili globali ******************************
*--------------------------------------|--------------------------------------*/

/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Verifica se str2 e' compresa in str1 (case insensitive)
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */

const char * stristr(const char *str1, const char *str2)
{
	int 		len1;
	int 		len2;
	const char*	p;

	if(!*str2)
		return((char *)str1);

	len1	=	strlen(str1);
	len2	=	strlen(str2);
	p		=	str1;

	while(*p)
	{
		if(toupper(*p)==toupper(*str2))
		{
			if(!strnicmp(p, str2, len2))
				return p;

			if((int)(p-str1)+len2 < len1)
			{
				p+=len2;
				continue;
			}
			else
				return NULL;
		}
		else
			p++;
	}

	return NULL;
}

/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Salta i caratteri di spazio e fa' avanzare il puntatore
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */

void skipSpace(const char** s)
{
	while ( isspace ( **s ) && **s )
		(*s)++;
}

/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Salta i caratteri di spazio e '=' e fa' avanzare il puntatore
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */

static	void skipSpaceAndEqual(const char** s)
{
	while ( (isspace ( **s ) || **s == '=') && **s )
		(*s)++;
}

/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Ritorna il path di WIN.INI
 *       Funziona solo da una shell di DOS
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */
#if 0
char*	getWinIni(char	*szBuffer, int	iBufferLen)
{
	char*	ptr;
	ptr 	= getenv("windir");

	strncpy(szBuffer, ptr, iBufferLen);
	strncat(szBuffer, "\\WIN.INI", iBufferLen);

	return	szBuffer;
}
#endif
/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Ritorna una linea da uno stream di testo tagliando il \n finale
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */

char *fgetline(char *s, int n, FILE *stream)
{
	char*	p;
	char*	d;

	if(NULL!=(p=fgets(s, n, stream)))
	{
		d=&s[strlen(s)-1];

		if(*d=='\n' || *d=='\r')
			*d = 0;
	}

	return p;
}

/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Compara il contenuto di una linea con l'elemento passato
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */

BOOL	compare(const char* cpsz_Line, const char* cpsz_Element, int i_Len)
{
	//	Se la lunghezza specificata e' maggiore di zero allora esegui una
	//	semplice comparazione di stringhe

	if(i_Len > 0)
	{
		if(0 == strnicmp( cpsz_Line, cpsz_Element, i_Len))
			return TRUE;
	}

	//	Altrimenti se la lunghezza e' uguale a zero ....

	else	if(i_Len == 0)
	{
		//	Posizionati nel segno di uguale '='

		const char *cp_s = strchr(cpsz_Line, '=');

		//	Se lo trovi cerca il primo carattere prima dell'uguale (saltando gli spazi)

		if(cp_s)
		{
			while ( (cp_s > cpsz_Line) && isspace ( *--cp_s ));

			i_Len = max((unsigned int)(cp_s - cpsz_Line), strlen(cpsz_Element));
		}

		//	Altrimenti la lunghezza della stringa con cui eseguire il confronto
		//	e' uguale alla lunghezza effettiva della stringa

		else
			i_Len = strlen(cpsz_Element);

		if(0 == strnicmp( cpsz_Line, cpsz_Element, i_Len))
			return TRUE;

	}

	return FALSE;
}

/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Ritorna vero o falso se all'interno di una linea c'e' la stringa specificata
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */

BOOL	match(const char* cpsz_Line, const char* cpsz_ElementName, char* lpszReturnBuffer, int cbReturnBuffer, FILE* fp)
{
	char	szLine[256];
	const char *pc_s =	cpsz_Line;
	const char *pc_c;

	skipSpace(&pc_s);

	if((pc_c=strchr(pc_s,';'))!=NULL || /* (pc_c=strchr(pc_s,'!'))!=NULL ||*/ ((pc_c=strchr(pc_s,'/'))!=NULL && (*(pc_c+1) == '/')))
	{
		if(compare(pc_s, cpsz_ElementName, (int)(pc_c-pc_s)))
			return TRUE;
	}
	else if((pc_c=stristr(pc_s, "/*"))!=NULL)
	{
		if(compare(pc_s, cpsz_ElementName, (int)(pc_c-pc_s)))
			return TRUE;

		if(ferror(fp))
			return FALSE;

		while(TRUE)
		{
			if(NULL==fgetline(szLine, sizeof(szLine), fp))
				return FALSE;

			if(stristr(szLine, "*/"))
			{
				if(strlen(szLine) <= cbReturnBuffer)
					strcpy(lpszReturnBuffer ,szLine);

				return FALSE;
			}
		}
	}
	else if((pc_c=stristr(pc_s, "*/"))!=NULL)
	{
		return FALSE;
	}
	else
	{
		if(compare(pc_s, cpsz_ElementName, 0))
			return TRUE;
	}

	return FALSE;
}

/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Estrae il valore di un elemento
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */

BOOL	extractValue(const char* cpsz_ItemName, const char* cp_p, char*	lpszReturnBuffer, int cbReturnBuffer)
{
	unsigned int	w_pos;

	const char* cp_d;

	int	  len	  =	strlen(cpsz_ItemName);

	if((cp_d=stristr( cp_p, cpsz_ItemName))!=NULL)
	{
		w_pos = (unsigned int)(cp_d - cp_p);

		w_pos+=len;

		cp_p += w_pos;

		skipSpaceAndEqual(&cp_p);

		if(*cp_p)
		{
			BOOL			b_apici 	= 	FALSE;
			BOOL			b_escape	=	FALSE;
			BOOL			b_end	  	=	FALSE;
			unsigned int	w_offset	=	0;

			while(!b_end && (w_pos+w_offset) < len)
			{
				switch(*(cp_p+w_offset))
				{
					case	'"':
						b_apici = (b_apici) ? FALSE : TRUE;
						break;

					case	'\\':
						b_escape = TRUE;
						break;

					case	';':
					case	'!':
						if(!b_escape && !b_apici)
							b_end=TRUE;
						break;

					case	'/':
						if(!b_escape && !b_apici && (*(cp_p+w_pos+1) == '/' || *(cp_p+w_pos+1) == '*'))
							b_end=TRUE;
						break;

					default:
						break;
				}

				w_offset++;
			}

			if(strlen(cp_p) > cbReturnBuffer)
				return FALSE;

			strcpy(lpszReturnBuffer, cp_p);

			if(w_offset)
				lpszReturnBuffer[--w_offset]	=	0;

			return TRUE;
		}
	}

	return FALSE;
}

/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Trova e riporta il valore di una item come stringa da un profile file specificato
 *		 Vedi le info dell'sdk allegate sul funzionamento
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */

/*
  GetPrivateProfileString (3.0)
 
 Declaration:
  int GetPrivateProfileString(lpszSection, lpszEntry, lpszDefault,
	lpszReturnBuffer, cbReturnBuffer, lpszFilename)

  LPCSTR lpszSection;          // address of section
  LPCSTR lpszEntry;            // address of entry
  LPCSTR lpszDefault;          // address of default string
  LPSTR lpszReturnBuffer;      // address of destination buffer
  int cbReturnBuffer;          // size of destination buffer
  LPCSTR lpszFilename;         // address of initialization filename

The GetPrivateProfileString function retrieves a character string from the
specified section in the specified initialization file.

 Parameter         Description
 
 lpszSection       Points to a null-terminated string that specifies the
                   section containing the entry.
                  
 lpszEntry         Points to the null-terminated string containing the
                   entry whose associated string is to be retrieved. If
                   this value is NULL, all entries in the section specified
				   by the lpszSection parameter are copied to the buffer
				   specified by the lpszReturnBuffer parameter. For more
				   information, see the following Comments section.
				  
 lpszDefault       Points to a null-terminated string that specifies the
                   default value for the given entry if the entry cannot
                   be found in the initialization file. This parameter must
                   never be NULL.
				  
 lpszReturnBuffer  Points to the buffer that receives the character string.
                  
 cbReturnBuffer    Specifies the size, in bytes, of the buffer pointed to
				   by the lpszReturnBuffer parameter.
				  
 lpszFilename      Points to a null-terminated string that names the
                   initialization file. If this parameter does not contain
                   a full path, Windows searches for the file in the
				   Windows directory.

 Returns:
The return value specifies the number of bytes copied to the specified
buffer, not including the terminating null character.

 Comments:
The function searches the file for an entry that matches the name specified
by the lpszEntry parameter under the section heading specified by the
lpszSection parameter. If the entry is found, its corresponding string is
copied to the buffer.

If the entry does not exist, the default character string specified by the
lpszDefault parameter is copied. A string entry in the initialization file
must have the following form:

 [section]
 entry=string
       .
	   .
	   .

If lpszEntry is NULL, the GetPrivateProfileString function copies all
entries in the specified section to the supplied buffer. Each string will be
null-terminated, with the final string ending with two zero-termination
characters. If the supplied destination buffer is too small to hold all the
strings, the last string will be truncated and followed with two
zero-termination characters.

If the string associated with lpszEntry is enclosed in single or double
quotation marks, the marks are discarded when GetPrivateProfileString
returns the string.

GetPrivateProfileString is not case-dependent, so the strings in lpszSection
and lpszEntry may contain a combination of uppercase and lowercase letters.

An application can use the GetProfileString function to retrieve a string
from the WIN.INI file.

The lpszDefault parameter must point to a valid string, even if the string
is empty (its first character is zero).

 Example:
The following example uses the GetPrivateProfileString function to determine
the last file saved by the [MyApp] application by reading the LastFile entry
in TESTCODE.INI:


 char szMsg[144], szBuf[80];

 GetPrivateProfileString("MyApp", "LastFile",
	 "", szBuf, sizeof(szBuf), "testcode.ini");

 sprintf(szMsg, "last file was %s", szBuf);
*/

int GetPrivateProfileString
(
	const char*	lpszSection,				// address of section
	const char*	lpszEntry,					// address of entry
	const char*	lpszDefault,				// address of default string
	char*		lpszReturnBuffer,			// address of destination buffer
	int			cbReturnBuffer,				// size of destination buffer
	const char*	lpszFilename				// address of initialization filename
)
{
	FILE*	fp;
	char	szSection[128];
	char	szLine[256];
	BOOL	b_match;
	BOOL	b_found;
	const 	char *pc_s;

	b_match=FALSE;
	b_found=FALSE;

	if(NULL==(fp=fopen(lpszFilename, "r")))
		return FALSE;

	if((strlen(lpszSection)+3) > sizeof(szSection))
		return FALSE;

	if(strlen(lpszSection))
	{
		strcpy(szSection+1, lpszSection);

		szSection[0]='[';

		strcat(szSection, "]");

		while(NULL!=fgetline(szLine, sizeof(szLine), fp))
		{
			if(TRUE==(b_match=match(szLine, szSection, szLine, sizeof(szLine), fp)))
				break;
		}

		if(b_match==FALSE)
		{
			fclose(fp);

			if(strlen(lpszDefault) <= cbReturnBuffer)
				strcpy(lpszReturnBuffer, lpszDefault);

			return FALSE;
		}
	}

	b_match=FALSE;

	while(NULL!=fgetline(szLine, sizeof(szLine), fp))
	{
		pc_s=szLine;

		//	Ricercando il valore di un item cercalo sono in una sezione

		skipSpace(&pc_s);
/*
		if( strchr(pc_s,'[') !=NULL )
			break;
*/
		if(TRUE==(b_match=match(szLine, lpszEntry, szLine, sizeof(szLine), fp)))
			break;
	}

	if(b_match==FALSE)
	{
		fclose(fp);

		if(strlen(lpszDefault) <= cbReturnBuffer)
			strcpy(lpszReturnBuffer, lpszDefault);

		return FALSE;
	}

	if(FALSE == (b_found	=	extractValue(lpszEntry, szLine, lpszReturnBuffer, cbReturnBuffer)))
	{
		if(strlen(lpszDefault) <= cbReturnBuffer)
			strcpy(lpszReturnBuffer, lpszDefault);
	}

	fclose(fp);

	return	b_found;
}

/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Trova e riporta il valore di una item come intero da un profile file specificato
 *		 Vedi le info dell'sdk allegate sul funzionamento
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */

/*
	GetPrivateProfileInt (3.0)
 

  UINT GetPrivateProfileInt(lpszSection, lpszEntry, default, lpszFilename)

  LPCSTR lpszSection;       // address of section
  LPCSTR lpszEntry;         // address of entry
  int default;              // return value if entry not found
  LPCSTR lpszFilename;      // address of initialization filename

The GetPrivateProfileInt function retrieves the value of an integer from an
entry within a specified section of a specified initialization file.

 Parameter     Description
 
 lpszSection   Points to a null-terminated string containing the section
               heading in the initialization file.
              
 lpszEntry     Points to the null-terminated string containing the entry
               whose value is to be retrieved.
              
 default       Specifies the default value to return if the entry cannot be
			   found in the initialization file. This value must be a
               positive integer in the range 0 through 32,767 (0x0000
			   through 0x7FFF).
              
 lpszFilename  Points to a null-terminated string that names the
               initialization file. If this parameter does not contain a
               full path, Windows searches for the file in the Windows
               directory.

 Returns:
The return value is the integer value of the specified entry if the function
is successful. It is the value of the default parameter if the function does
not find the entry. The return value is zero if the value that corresponds
to the specified entry is not an integer.

 Comments:
The function searches the file for an entry that matches the name specified
by the lpszEntry parameter under the section heading specified by the
lpszSection parameter. An integer entry in the initialization file must have
the following form:

 [section]
 entry=value
       .
       .
       .

If the value that corresponds to the entry consists of digits followed by
nonnumeric characters, the function returns the value of the digits. For
example, the function would return 102 for the line "Entry=102abc".

The GetPrivateProfileInt function is not case-dependent, so the strings in
the lpszSection and lpszEntry parameters may contain a combination of
uppercase and lowercase letters.

GetPrivateProfileInt supports hexadecimal notation. When
GetPrivateProfileInt is used to retrieve a negative integer, the value
should be cast to an int.

An application can use the GetProfileInt function to retrieve an integer
value from the WIN.INI file.

 Example:
The following example uses the GetPrivateProfileInt function to retrieve the
last line number by reading the LastLine entry from the [MyApp] section of
TESTCODE.INI:


 WORD wInt;
 char szMsg[144];

 wInt = GetPrivateProfileInt("MyApp", "LastLine",
	 0, "testcode.ini");

 sprintf(szMsg, "last line was %d", wInt);
*/


unsigned int GetPrivateProfileInt
(
	const char* lpszSection,			// address of section
	const char* lpszEntry,             	// address of entry
	int 		idefault,               // return value if entry not found
	const char *lpszFilename            // address of initialization filename
)
{
	char szBuffer[80];

	if(GetPrivateProfileString(lpszSection, lpszEntry, "", szBuffer, sizeof(szBuffer), lpszFilename))
	{
		return atoi(szBuffer);
	}

	return idefault;
}
#if 0
/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Trova e riporta il valore di una item come int da WIN.INI
 *		 Funziona solo in una finestra dos o in DOS DPMI
 *		 Vedi le info dell'sdk allegate sul funzionamento
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */

/*
  GetProfileInt (2.x)
 
What has changed

 Declaration:
  UINT GetProfileInt(lpszSection, lpszEntry, default)

  LPCSTR lpszSection;  // address of section
  LPCSTR lpszEntry;    // address of entry
  int default;         // return value if entry is not found

The GetProfileInt function retrieves the value of an integer from an entry
within a specified section of the WIN.INI initialization file.

 Parameter    Description
 
 lpszSection  Points to a null-terminated string that specifies the section
			  containing the entry.
			 
 lpszEntry    Points to the null-terminated string containing the entry
			  whose value is to be retrieved.
			 
 default      Specifies the default value to return if the entry cannot be
			  found. This value can be an unsigned value in the range 0
			  through 65,536 or a signed value in the range -32,768 through
			  32,768. Hexadecimal notation is accepted for both positive
			  and negative values.

 Returns:
The return value is the integer value of the string following the specified
entry, if the function is successful. The return value is the value of the
default parameter if the function does not find the entry. The return value
is zero if the value that corresponds to the specified entry is not an
integer.

 Comments:
The GetProfileInt function is not case-dependent, so the strings in the
lpszSection and lpszEntry parameters may contain a combination of uppercase
and lowercase letters.

GetProfileInt supports hexadecimal notation. When the function is used to
retrieve a negative integer, the value should be cast to an int.

An integer entry in the WIN.INI file must have the following form:

 [section]
 entry=value
     .
     .
     .

If the value that corresponds to the entry consists of digits followed by
nonnumeric characters, the function returns the value of the digits. For
example, the function would return 102 for the line "Entry=102abc".

An application can use the GetPrivateProfileInt function to retrieve an
integer from a specified file.

 Example:
The following example uses the GetProfileInt function to retrieve the
screen-save timeout time from the WIN.INI file:
*/

unsigned int	GetProfileInt
(
  const char*	lpszSection,  // address of section
  const char*	lpszEntry,    // address of entry
  int 			idefault      // return value if entry is not found
)
{
	char	sz_winIni[MAXPATH];

	if(getWinIni(sz_winIni, sizeof(sz_winIni)))
		return	GetPrivateProfileInt(lpszSection, lpszEntry, idefault, sz_winIni);

	return	idefault;
}

/*
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Creazione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Creatore : Marco Savegnago               Data di creazione : 21/11/1995
 * Codice   :
 *
 * Note: Trova e riporta il valore di una item come stringa da WIN.INI
 *		 Funziona solo in una finestra dos o in DOS DPMI
 *		 Vedi le info dell'sdk allegate sul funzionamento
 *
 *>>>>>>>>>>>>>>>>>>>>>>>>>>> Revisione funzione <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 *-------------------------------------|--------------------------------------*
 * Revisore :                                  Data di revisione :
 * Versione : 0
 *
 * Note:
 *
 */

/*
  GetProfileString (2.x)
 
 Declaration:
  int GetProfileString(lpszSection, lpszEntry, lpszDefault, lpszReturnBuffer,
	cbReturnBuffer)

  LPCSTR lpszSection;        // address of section
  LPCSTR lpszEntry;          // address of entry
  LPCSTR lpszDefault;        // address of default string
  LPSTR lpszReturnBuffer;    // address of destination buffer
  int cbReturnBuffer;        // size of destination buffer

The GetProfileString function retrieves the string associated with an entry
within the specified section in the WIN.INI initialization file.

 Parameter         Description
 
 lpszSection       Points to a null-terminated string that specifies the
				   section containing the entry.
                  
 lpszEntry         Points to the null-terminated string containing the
				   entry whose associated string is to be retrieved. If
                   this value is NULL, all entries in the section
				   specified by the lpszSection parameter are copied to
                   the buffer specified by the lpszReturnBuffer parameter.
                  
				   For more information, see the following Comments
                   section.
                  
 lpszDefault       Points to the default value for the given entry if the
                   entry cannot be found in the initialization file. This
				   parameter must never be NULL.
                  
 lpszReturnBuffer  Points to the buffer that will receive the character
string.           
                  
 cbReturnBuffer    Specifies the size, in bytes, of the buffer pointed to
                   by the lpszReturnBuffer parameter.

 Returns:
The return value is the number of bytes copied to the buffer, not including
the terminating zero, if the function is successful.

 Comments:
If the lpszEntry parameter is NULL, the GetProfileString function copies all
entries in the specified section to the supplied buffer. Each string will be
null-terminated, with the final string terminating with two null characters.
If the supplied destination buffer is too small to hold all the strings, the
last string will be truncated and followed by two terminating null
characters.

If the string associated with lpszEntry is enclosed in single or double
quotation marks, the marks are discarded when GetProfileString returns the
string.

GetProfileString is not case-dependent, so the strings in the lpszSection
and lpszEntry parameters may contain a combination of uppercase and
lowercase letters.

A string entry in the WIN.INI file must have the following form:

 [section]
 entry=string
     .
     .
	 .

An application can use the GetPrivateProfileString function to retrieve a
string from a specified file.

The lpszDefault parameter must point to a valid string, even if the string
is empty (its first character is zero).

 Example:
The following example uses the GetProfileString function to list all the
entries and strings in the [windows] section of the WIN.INI file:


 int c, cc;
 PSTR pszBuf, pszKey;
 char szMsg[80], szVal[80];

 // Allocate a buffer for the entries.

 pszBuf = (PSTR) LocalAlloc(LMEM_FIXED, 1024);

 // Retrieve all the entries in the [windows] section.

 GetProfileString("windows", NULL, "", pszBuf, 1024);

  //
  //  Retrieve the string for each entry, until
  //  reaching the double null character.
  //

 for (pszKey = pszBuf, c = 0;
		 *pszKey != '\0'; pszKey += strlen(pszKey) + 1) {

	 // Retrieve the value for each entry in the buffer.

	 GetProfileString("windows", pszKey, "not found",
		 szVal, sizeof(szVal));

	 cc = sprintf(szMsg, "%s = %s", pszKey, szVal);
	 TextOut(hdc, 10, 15 * c++, szMsg, cc);
 }
*/

int GetProfileString
(
  const char*	lpszSection,        	// address of section
  const char*	lpszEntry,          	// address of entry
  const char*	lpszDefault,        	// address of default string
  char*			lpszReturnBuffer,    	// address of destination buffer
  int 			cbReturnBuffer        	// size of destination buffer
)
{
	char	sz_winIni[MAXPATH];

	if(getWinIni(sz_winIni, sizeof(sz_winIni)))
		return	GetPrivateProfileString(lpszSection, lpszEntry, lpszDefault, lpszReturnBuffer, cbReturnBuffer, sz_winIni);

	if(strlen(lpszDefault) <= cbReturnBuffer)
	{
		strcpy(lpszReturnBuffer, lpszDefault);
		return TRUE;
	}

	return FALSE;
}
#endif
#if 0
void	main(void)
{
	char szBuf[80];
	unsigned int	iInt;

	GetPrivateProfileString("SECTION1", "ITEM1", "DEFAULT", szBuf, sizeof(szBuf), "PROVA.INI");

	iInt = GetPrivateProfileInt("SECTION1", "ITEM2", 0, "PROVA.INI");

	GetProfileString("WINDOWS", "device", "none", szBuf, sizeof(szBuf));

	iInt = GetProfileInt("WINDOWS", "DoubleClickSpeed", 0);

	//	avoid warning;

	iInt = iInt;
}
#endif
